pub struct NominalFrequency;Expand description
ACPI Specification 6.5; 8.4.6.1.1.2 Nominal Performance
Nominal Performance is the maximum sustained performance level of the processor, assuming ideal operating conditions. In absence of an external constraint (power, thermal, etc.) this is the performance level the platform is expected to be able to maintain continuously. All processors are expected to be able to sustain their nominal performance state simultaneously.